@@ -72,7 +72,7 @@ targets::tar_test("tar_map() manifest", {
     )
   })
   out <- targets::tar_manifest(callr_function = NULL)
-  expect_equal(dim(out), c(4, 3))
+  expect_equal(dim(out), c(4, 4))
   names <- c("x_12_56", "x_34_78", "y_12_56", "y_34_78")
   expect_equal(sort(out$name), sort(c(names)))
   expect_equal(out$command[out$name == "x_12_56"], "12 + 56")
@@ -171,3 +171,91 @@ targets::tar_test("tar_map() is not sensitive to ordering (#67)", {
   out <- targets::tar_progress()
   expect_equal(unique(out$progress), "skipped")
 })
+
+targets::tar_test("tar_map() default descriptions", {
+  skip_on_cran()
+  targets::tar_script({
+    library(targets)
+    tar_map(
+      values = list(
+        name = letters[seq_len(4L)]
+      ),
+      descriptions = NULL,
+      tar_target(x, 1)
+    )
+  })
+  manifest <- targets::tar_manifest(
+    callr_function = NULL,
+    fields = tidyselect::any_of("description"),
+    drop_missing = FALSE
+  )
+  expect_true(all(is.na(manifest$description)))
+})
+
+targets::tar_test("tar_map() description from target only", {
+  skip_on_cran()
+  targets::tar_script({
+    library(targets)
+    tar_map(
+      values = list(
+        name = letters[seq_len(4L)]
+      ),
+      descriptions = NULL,
+      tar_target(x, 1, description = "info")
+    )
+  })
+  manifest <- targets::tar_manifest(
+    callr_function = NULL,
+    fields = tidyselect::any_of("description"),
+    drop_missing = FALSE
+  )
+  expect_equal(manifest$description, rep("info", 4L))
+})
+
+targets::tar_test("tar_map() description from values only", {
+  skip_on_cran()
+  targets::tar_script({
+    library(targets)
+    tar_map(
+      values = list(
+        name = letters[seq_len(4L)],
+        blurb = as.character(seq_len(4L))
+      ),
+      names = tidyselect::any_of("name"),
+      descriptions = tidyselect::any_of("blurb"),
+      tar_target(x, 1)
+    )
+  })
+  manifest <- targets::tar_manifest(
+    callr_function = NULL,
+    fields = tidyselect::any_of("description"),
+    drop_missing = FALSE
+  )
+  expect_equal(manifest$description, as.character(seq_len(4L)))
+})
+
+targets::tar_test("tar_map() description from both targets and values", {
+  skip_on_cran()
+  targets::tar_script({
+    library(targets)
+    tar_map(
+      values = list(
+        name = letters[seq_len(4L)],
+        blurb = as.character(seq_len(4L)),
+        blurb2 = c("w", "x", "y", "z")
+      ),
+      names = tidyselect::any_of("name"),
+      descriptions = tidyselect::any_of(c("blurb", "blurb2")),
+      tar_target(x, 1, description = "info")
+    )
+  })
+  manifest <- targets::tar_manifest(
+    callr_function = NULL,
+    fields = tidyselect::any_of("description"),
+    drop_missing = FALSE
+  )
+  expect_equal(
+    manifest$description,
+    paste("info", seq_len(4L), c("w", "x", "y", "z"))
+  )
+})
